#ifndef WEIGHTSETTINGS_H
#define WEIGHTSETTINGS_H

#include <QtGui>
#include "xml.h"
#include <QMaemo5ValueButton>
#include <QMaemo5ListPickSelector>

class WeightSettings : public QDialog
{
    Q_OBJECT
public:
    explicit WeightSettings(QWidget *parent = 0);
    void load();

signals:

private slots:
    void orientationChanged();

private:
    XML *xml;

    void save();
    void closeEvent(QCloseEvent *event);

    QPushButton *btnSave;

    QStandardItemModel *modelSet;
    QStandardItemModel *modelMin;
    QStandardItemModel *modelSec;


    QMaemo5ValueButton *btnSet;
    QMaemo5ValueButton *btnMin;
    QMaemo5ValueButton *btnSec;


    QMaemo5ListPickSelector *selectorSet;
    QMaemo5ListPickSelector *selectorMin;
    QMaemo5ListPickSelector *selectorSec;

};

#endif // WEIGHTSETTINGS_H
